==> dyedvoid-1.0.3%2Bmc1.21.1-sources.jar: archives/tater/dyedvoid/mixin/GlassBottleItemMixin.java <==
package archives.tater.dyedvoid.mixin;

import archives.tater.dyedvoid.DyedVoidItems;
import archives.tater.dyedvoid.DyedVoidSounds;
import com.llamalad7.mixinextras.sugar.Local;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1657;
import net.minecraft.class_1754;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_239;
import net.minecraft.class_3419;
import net.minecraft.class_3965;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1754.class)
public class GlassBottleItemMixin extends class_1792 {
    public GlassBottleItemMixin(class_1793 settings) {
        super(settings);
    }

    @Inject(
            method = "use",
            at = @At(value = "INVOKE", target = "Lnet/minecraft/util/TypedActionResult;pass(Ljava/lang/Object;)Lnet/minecraft/util/TypedActionResult;", ordinal = 0),
            cancellable = true)
    private void getVoidBottle(class_1937 world, class_1657 user, class_1268 hand, CallbackInfoReturnable<class_1271<class_1799>> cir, @Local class_3965 blockHitResult) {
        if (blockHitResult.method_17783() == class_239.class_240.field_1333 && blockHitResult.method_17777().method_10264() < world.method_31607()) {
            var stack = user.method_5998(hand);
            if (stack.method_7947() > 1 || user.method_7337()) {
                if (!user.method_7337()) {
                    stack.method_7934(1);
                }
                user.method_7270(new class_1799(DyedVoidItems.VOID_BOTTLE_ITEM));
            } else {
                user.method_6122(hand, new class_1799(DyedVoidItems.VOID_BOTTLE_ITEM));
            }
            world.method_43128(null, user.method_23317(), user.method_23318(), user.method_23321(), DyedVoidSounds.FILL_VOID_BOTTLE, class_3419.field_15254, 1.0F, 1.0F);
            cir.setReturnValue(class_1271.method_22427(stack));
        }
    }
}

==> dyedvoid-1.0.4%2Bmc1.21.10-sources.jar: archives/tater/dyedvoid/mixin/GlassBottleItemMixin.java <==
package archives.tater.dyedvoid.mixin;

import archives.tater.dyedvoid.DyedVoidItems;
import archives.tater.dyedvoid.DyedVoidSounds;
import com.llamalad7.mixinextras.sugar.Local;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1754;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_239;
import net.minecraft.class_3419;
import net.minecraft.class_3965;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(class_1754.class)
public class GlassBottleItemMixin extends class_1792 {
    public GlassBottleItemMixin(class_1793 settings) {
        super(settings);
    }

    @Inject(
            method = "use",
            at = @At(value = "FIELD", target = "Lnet/minecraft/util/ActionResult;PASS:Lnet/minecraft/util/ActionResult$Pass;", ordinal = 0),
            cancellable = true
    )
    private void getVoidBottle(class_1937 world, class_1657 user, class_1268 hand, CallbackInfoReturnable<class_1269> cir, @Local class_3965 blockHitResult) {
        if (blockHitResult.method_17783() == class_239.class_240.field_1333 && blockHitResult.method_17777().method_10264() < world.method_31607()) {
            var stack = user.method_5998(hand);
            if (stack.method_7947() > 1 || user.method_68878()) {
                if (!user.method_68878()) {
                    stack.method_7934(1);
                }
                user.method_7270(new class_1799(DyedVoidItems.VOID_BOTTLE_ITEM));
            } else {
                user.method_6122(hand, new class_1799(DyedVoidItems.VOID_BOTTLE_ITEM));
            }
            world.method_43128(null, user.method_23317(), user.method_23318(), user.method_23321(), DyedVoidSounds.FILL_VOID_BOTTLE, class_3419.field_15254, 1.0F, 1.0F);
            cir.setReturnValue(class_1269.field_5812.method_61393(stack));
        }
    }
}
